#!/usr/local/bin/perl
#
# PAPI Shibboleth Auth functions
#
# These functions implement PAPI credential data provision using the
# information obtained from a SP Shibboleth

package PAPI::ShibAuth;
use strict;
use POSIX qw(strftime);

# This function is intended to be hooked at the credentialHook in a PAPI
# AuthServer.
sub VerifyUser {
	my $con = shift;
	my $cfg = shift;
	my $user_header = undef;
	my $username = "";

	$user_header = $$cfg{'SHIBUserHeader'} if (exists $$cfg{'SHIBUserHeader'});
	if (!defined $user_header) {
		$$con{'PAPIerror'} = "Configuration error: SHIBUserHeader needed";
		return undef;
	}
	$username=$ENV{$user_header};
	return $username;
}

# This function is intended to be hooked at the credentialHook in a PAPI
# AuthServer.
sub UserCredentials {
	my $con = shift;
	my $cfg = shift;
	my $user_header = undef;
	my @retar = ();
   
	$user_header = $$cfg{'SHIBUserHeader'} if (exists $$cfg{'SHIBUserHeader'});
	if (!defined $user_header) {
		$$con{'PAPIerror'} = "Configuration error: SHIBUserHeader needed";
        return \@retar;
	}
	push @retar, {};
	return \@retar;
}


# This function is intended to be hooked at the attrRequestHook in a PAPI
# AuthServer.
sub UserAttributes {
	my $con = shift;
   	my $cfg = shift;
	my $user_header = undef;
	my @retar = (0, "");
	my $var = undef;
	my $val = undef;

	$user_header = $$cfg{'SHIBUserHeader'} if (exists $$cfg{'SHIBUserHeader'});
	if (!defined $user_header) {
		$$con{'PAPIerror'} = "Configuration error: SHIBUserHeader needed";
        return \@retar;
	}
	my %shibListAttr=$$cfg{'SHIBListAttr'};
   
	foreach $var (keys(%shibListAttr)) {
    	$val = $ENV{$var};
    	$$con{$var}=$val;
    }
	$retar[0] = $$cfg{'defTimeToLive'};
	$retar[1] = $$cfg{'defAssertion'};
	return @retar;
}

1;
